<?php
/*
 +-------------------------------------------------------------------------+
 | Copyright (C) 2004-2018 The Cacti Group                                 |
 |                                                                         |
 | This program is free software; you can redistribute it and/or           |
 | modify it under the terms of the GNU General Public License             |
 | as published by the Free Software Foundation; either version 2          |
 | of the License, or (at your option) any later version.                  |
 |                                                                         |
 | This program is distributed in the hope that it will be useful,         |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
 | GNU General Public License for more details.                            |
 +-------------------------------------------------------------------------+
 | Cacti: The Complete RRDtool-based Graphing Solution                     |
 +-------------------------------------------------------------------------+
 | This code is designed, written, and maintained by the Cacti Group. See  |
 | about.php and/or the AUTHORS file for specific developer information.   |
 +-------------------------------------------------------------------------+
 | http://www.cacti.net/                                                   |
 +-------------------------------------------------------------------------+
*/

function upgrade_to_1_1_11() {
	db_install_execute('ALTER TABLE poller_data_template_field_mappings
		MODIFY COLUMN data_name VARCHAR(40) NOT NULL DEFAULT "",
		MODIFY COLUMN data_source_names VARCHAR(125) NOT NULL DEFAULT ""');

	// required for tne new plugin structure
	db_install_execute('DELETE FROM settings WHERE name LIKE "md5%_plugins"');
	db_install_execute('DELETE FROM poller_resource_cache WHERE path LIKE "plugins/%"');
}
